@@ -16,7 +16,7 @@
 # endif
 
 #else
-# error Missing macro definitions!. Use this include file only when running Escher C verifier.
+# error "Missing macro definitions!. Use this include file only when running Escher C verifier."
 #endif
 
 #endif
