@@ -14,7 +14,7 @@
 int isalnum(int);
 int isalpha(int);
 
-# if defined(__STDC_VERSION__) && (__STDC_VERSION__ >= 199901L)
+# if (defined(__STDC_VERSION__) && (__STDC_VERSION__ >= 199901L)) || (defined(__cplusplus) && (__cplusplus >= 201103L))
 int isblank(int);
 # endif
 
@@ -32,7 +32,7 @@ int tolower(int);
 int toupper(int);
 
 #else
-# error Missing macro definitions!. Use this include file only when running Escher C verifier.
+# error "Missing macro definitions! Use this include file only when running Escher C verifier."
 #endif
 
 #endif
