@@ -11,14 +11,14 @@
 
 # if !defined(_ecv_va_list_defined)
 #  define _ecv_va_list_defined
-typedef struct { const char* _ecv_array _ecv_null p; unsigned int s; } va_list;
+typedef struct { const void* _ecv_null p; unsigned int s; } va_list;
 # endif
 
-# define va_start(_x, _parmN)	{ (_x).p = reinterpret_cast<const char* _ecv_array>(&_parmN); (_x).s = static_cast<unsigned int>(sizeof(_parmN)); }
-# define va_arg(_x, _t)        	( (_x).p += (_x).s, (_x).s = static_cast<unsigned int>(sizeof(_t)), *reinterpret_cast<_t*>(_x) )
+# define va_start(_x, _parmN)	{ (_x) = (va_list){ reinterpret_cast<const void*>(&_parmN), static_cast<unsigned int>(sizeof(_parmN))}; }
+# define va_arg(_x, _t)        	( (_x).p = reinterpret_cast<const void*>(reinterpret_cast<const char*>((_x).p) + (_x).s), (_x).s = static_cast<unsigned int>(sizeof(_t)), *reinterpret_cast<_t*>(_x) )
 # define va_end(_x)				{ (_x).p = 0; }
 
-# if defined(__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
+# if (defined(__STDC_VERSION__) && (__STDC_VERSION__ >= 199901L)) || (defined(__cplusplus) && (__cplusplus >= 201103L))
 #  define va_copy(_dst, _src)	{ _dst = _src }
 # endif
 
