@@ -22,7 +22,7 @@ typedef struct { int dummy; } wctrans_t;
 int iswalnum(wint_t);
 int iswalpha(wint_t);
 
-# if defined(__STDC_VERSION__) && (__STDC_VERSION__ >= 199901L)
+# if (defined(__STDC_VERSION__) && (__STDC_VERSION__ >= 199901L)) || (defined(__cplusplus) && (__cplusplus >= 201103L))
 int iswblank(wint_t);
 # endif
 
@@ -51,7 +51,7 @@ wctype_t wctype(const char* _ecv_array);
 # endif
 
 #else
-# error Missing macro definitions!. Use this include file only when running Escher C verifier.
+# error "Missing macro definitions!. Use this include file only when running Escher C verifier."
 #endif
 
 #endif
