@@ -1441,6 +1441,15 @@ _eHndl<OsInfo> Environment :: getOsInfo() const
 	return _eosInterface :: getOsInfo();
 }
 
+//---------------------------------------------------------------------------------------------
+// Function: Environment :: getRuntimeLanguage()
+// Purpose:  Determine which language the runtime is written in
+//---------------------------------------------------------------------------------------------
+_eSeq<_eChar> Environment :: getRuntimeLanguage() const
+{
+	return _mString("c++");
+}
+
 //
 // Functions to allow the setting of the global runtime-check-enabling variables via the Environment
 //
